.. _projectors:

Projectors
==========

.. autoclass:: mumott.methods.projectors.SAXSProjectorCUDA
   :members:
   :inherited-members:

.. autoclass:: mumott.methods.projectors.SAXSProjectorAstra
   :members:
   :inherited-members:

.. autoclass:: mumott.methods.projectors.SAXSProjectorNumba
   :members:
   :inherited-members:

